@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2016 David Faure <faure@kde.org>
+  SPDX-FileCopyrightText: 2016 David Faure <faure@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "grantleethememanager.h"
@@ -83,14 +71,14 @@ void GrantleeThemeManagerTest::destructionOrderTest()
     QCOMPARE(manager->themes().count(), 2);
     QVERIFY(!manager->actionForTheme()); // Bug? No "default" theme.
 
-    QActionGroup *actionGroup = new QActionGroup(this);
+    auto *actionGroup = new QActionGroup(this);
     manager->setActionGroup(actionGroup);
 
-    KActionMenu *menu = new KActionMenu(this);
+    auto *menu = new KActionMenu(this);
     manager->setThemeMenu(menu);
     QCOMPARE(menu->menu()->actions().count(), 4); // 2 themes + separator + download
 
-    KActionMenu *menu2 = new KActionMenu(this);
+    auto *menu2 = new KActionMenu(this);
     manager->setThemeMenu(menu2);
     QCOMPARE(menu2->menu()->actions().count(), 4);
 
