@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Lesser General Public
-  License as published by the Free Software Foundation; either
-  version 2.1 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Lesser General Public License for more details.
-
-  You should have received a copy of the GNU Lesser General Public
-  License along with this library; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "grantleethememanager.h"
@@ -28,7 +16,6 @@
 #include <KNS3/DownloadDialog>
 #include <KAuthorized>
 #include <KActionMenu>
-#include <QDebug>
 #include <QAction>
 #include <QIcon>
 #include <QPointer>
@@ -45,8 +32,6 @@ public:
     Private(const QString &type, const QString &desktopFileName, KActionCollection *ac, const QString &relativePath, ThemeManager *qq)
         : applicationType(type)
         , defaultDesktopFileName(desktopFileName)
-        , actionGroup(nullptr)
-        , menu(nullptr)
         , actionCollection(ac)
         , q(qq)
     {
@@ -143,8 +128,12 @@ public:
                         theme.d->name = themeName;
                     }
                     alreadyLoadedThemeName << themeName;
-                    themes.insert(dirName, theme);
-                    //qDebug()<<" theme.name()"<<theme.name();
+                    auto it = themes.find(dirName);
+                    if (it != themes.end()) {
+                        (*it).addThemePath(dirIt.filePath());
+                    } else {
+                        themes.insert(dirName, theme);
+                    }
                 }
             }
             watch->addDir(directory);
@@ -233,7 +222,7 @@ public:
     void slotThemeSelected()
     {
         if (q->sender()) {
-            KToggleAction *act = qobject_cast<KToggleAction *>(q->sender());
+            auto *act = qobject_cast<KToggleAction *>(q->sender());
             selectTheme(act);
             Q_EMIT q->grantleeThemeSelected();
         }
@@ -274,12 +263,12 @@ public:
     KDirWatch *watch = nullptr;
     QActionGroup *actionGroup = nullptr;
     KActionMenu *menu = nullptr;
-    KActionCollection *actionCollection = nullptr;
+    KActionCollection *const actionCollection;
     QAction *separatorAction = nullptr;
 
     QAction *downloadThemesAction = nullptr;
     QPointer<KNS3::DownloadDialog> downloadThemesDialog;
-    ThemeManager *q;
+    ThemeManager *const q;
 };
 
 ThemeManager::ThemeManager(const QString &applicationType, const QString &defaultDesktopFileName, KActionCollection *actionCollection, const QString &path, QObject *parent)
